@@ -2,9 +2,9 @@ from pydantic import BaseModel, Field
 from typing import Dict
 
 try:
-    from typing import Literal  # type: ignore
+    from typing import Literal, Optional  # type: ignore
 except ImportError:
-    from typing_extensions import Literal  # type: ignore
+    from typing_extensions import Literal, Optional  # type: ignore
 from datetime import datetime
 
 
@@ -13,13 +13,13 @@ class GeneralStoreDoc(BaseModel):
     Defines general store data
     """
 
-    kind: Literal["newsfeed", "seminar", "banner"] = Field(
+    kind: Optional[Literal["newsfeed", "seminar", "banner"]] = Field(
         None, description="Type of the data."
     )
 
-    markdown: str = Field(None, description="Markdown data.")
+    markdown: Optional[str] = Field(None, description="Markdown data.")
 
-    meta: Dict = Field(None, description="Metadata.")
+    meta: Optional[Dict] = Field(None, description="Metadata.")
 
     last_updated: datetime = Field(
         description="Timestamp for when this document was last updated",
