@@ -1,4 +1,5 @@
 from pydantic import BaseModel, Field
+from typing import Optional
 
 
 class UserSettingsDoc(BaseModel):
@@ -6,11 +7,11 @@ class UserSettingsDoc(BaseModel):
     Defines data for user settings
     """
 
-    consumer_id: str = Field(
+    consumer_id: Optional[str] = Field(
         None, title="Consumer ID", description="Consumer ID for a specific user."
     )
 
-    settings: dict = Field(
+    settings: Optional[dict] = Field(
         None,
         title="Consumer ID settings",
         description="Settings defined for a specific user.",
