@@ -1,4 +1,5 @@
 from pydantic import Field, BaseModel
+from typing import Optional
 
 
 class FormulaAutocomplete(BaseModel):
@@ -6,7 +7,7 @@ class FormulaAutocomplete(BaseModel):
     Class defining formula autocomplete return data
     """
 
-    formula_pretty: str = Field(
+    formula_pretty: Optional[str] = Field(
         None,
         description="Human readable chemical formula.",
     )
