@@ -217,7 +217,7 @@ class Interaction(MSONable):
 
 
 class OrbitalDoc(PropertyDoc):
-    property_name = "natural bonding orbitals"
+    property_name: str = "natural bonding orbitals"
 
     # Always populated - closed-shell and open-shell
     open_shell: bool = Field(
@@ -229,49 +229,49 @@ class OrbitalDoc(PropertyDoc):
     )
 
     # Populated for closed-shell molecules
-    nbo_lone_pairs: List[LonePair] = Field(
+    nbo_lone_pairs: Optional[List[LonePair]] = Field(
         None, description="Lone pair orbitals of a closed-shell molecule"
     )
 
-    nbo_bonds: List[Bond] = Field(
+    nbo_bonds: Optional[List[Bond]] = Field(
         None, description="Bond-like orbitals of a closed-shell molecule"
     )
 
-    nbo_interactions: List[Interaction] = Field(
+    nbo_interactions: Optional[List[Interaction]] = Field(
         None, description="Orbital-orbital interactions of a closed-shell molecule"
     )
 
     # Populated for open-shell molecules
-    alpha_population: List[NaturalPopulation] = Field(
+    alpha_population: Optional[List[NaturalPopulation]] = Field(
         None,
         description="Natural electron populations of the alpha electrons of an "
         "open-shell molecule",
     )
-    beta_population: List[NaturalPopulation] = Field(
+    beta_population: Optional[List[NaturalPopulation]] = Field(
         None,
         description="Natural electron populations of the beta electrons of an "
         "open-shell molecule",
     )
 
-    alpha_lone_pairs: List[LonePair] = Field(
+    alpha_lone_pairs: Optional[List[LonePair]] = Field(
         None, description="Alpha electron lone pair orbitals of an open-shell molecule"
     )
-    beta_lone_pairs: List[LonePair] = Field(
+    beta_lone_pairs: Optional[List[LonePair]] = Field(
         None, description="Beta electron lone pair orbitals of an open-shell molecule"
     )
 
-    alpha_bonds: List[Bond] = Field(
+    alpha_bonds: Optional[List[Bond]] = Field(
         None, description="Alpha electron bond-like orbitals of an open-shell molecule"
     )
-    beta_bonds: List[Bond] = Field(
+    beta_bonds: Optional[List[Bond]] = Field(
         None, description="Beta electron bond-like orbitals of an open-shell molecule"
     )
 
-    alpha_interactions: List[Interaction] = Field(
+    alpha_interactions: Optional[List[Interaction]] = Field(
         None,
         description="Alpha electron orbital-orbital interactions of an open-shell molecule",
     )
-    beta_interactions: List[Interaction] = Field(
+    beta_interactions: Optional[List[Interaction]] = Field(
         None,
         description="Beta electron orbital-orbital interactions of an open-shell molecule",
     )
