@@ -40,7 +40,7 @@ class MoleculeSummaryDoc(PropertyDoc):
     Summary information about molecules and their properties, useful for searching.
     """
 
-    property_name = "summary"
+    property_name: str = "summary"
 
     # molecules
     molecules: Dict[str, Molecule] = Field(
@@ -48,26 +48,26 @@ class MoleculeSummaryDoc(PropertyDoc):
         description="The lowest energy optimized structures for this molecule for each solvent.",
     )
 
-    molecule_levels_of_theory: Dict[str, str] = Field(
+    molecule_levels_of_theory: Optional[Dict[str, str]] = Field(
         None,
         description="Level of theory used to optimize the best molecular structure for each solvent.",
     )
 
-    species_hash: str = Field(
+    species_hash: Optional[str] = Field(
         None,
         description="Weisfeiler Lehman (WL) graph hash using the atom species as the graph "
         "node attribute.",
     )
-    coord_hash: str = Field(
+    coord_hash: Optional[str] = Field(
         None,
         description="Weisfeiler Lehman (WL) graph hash using the atom coordinates as the graph "
         "node attribute.",
     )
 
-    inchi: str = Field(
+    inchi: Optional[str] = Field(
         None, description="International Chemical Identifier (InChI) for this molecule"
     )
-    inchi_key: str = Field(
+    inchi_key: Optional[str] = Field(
         None, description="Standardized hash of the InChI for this molecule"
     )
 
@@ -86,244 +86,244 @@ class MoleculeSummaryDoc(PropertyDoc):
         description="IDs of associated MoleculeDocs used to construct this molecule.",
     )
 
-    unique_calc_types: List[CalcType] = Field(
+    unique_calc_types: Optional[List[CalcType]] = Field(
         None,
         description="Collection of all unique calculation types used for this molecule",
     )
 
-    unique_task_types: List[TaskType] = Field(
+    unique_task_types: Optional[List[TaskType]] = Field(
         None,
         description="Collection of all unique task types used for this molecule",
     )
 
-    unique_levels_of_theory: List[LevelOfTheory] = Field(
+    unique_levels_of_theory: Optional[List[LevelOfTheory]] = Field(
         None,
         description="Collection of all unique levels of theory used for this molecule",
     )
 
-    unique_solvents: List[str] = Field(
+    unique_solvents: Optional[List[str]] = Field(
         None,
         description="Collection of all unique solvents (solvent parameters) used for this molecule",
     )
 
-    unique_lot_solvents: List[str] = Field(
+    unique_lot_solvents: Optional[List[str]] = Field(
         None,
         description="Collection of all unique combinations of level of theory and solvent used for this molecule",
     )
 
     # thermo
-    thermo_property_ids: Dict[str, str] = Field(
+    thermo_property_ids: Optional[Dict[str, str]] = Field(
         None,
         description="Solvent:property ID map for each MoleculeThermoDoc for this molecule.",
     )
 
-    thermo_levels_of_theory: Dict[str, str] = Field(
+    thermo_levels_of_theory: Optional[Dict[str, str]] = Field(
         None,
         description="Solvent:level of theory map for each MoleculeThermoDoc for this molecule.",
     )
 
-    electronic_energy: Dict[str, float] = Field(
+    electronic_energy: Optional[Dict[str, float]] = Field(
         None, description="Electronic energy of the molecule (units: eV)"
     )
 
-    zero_point_energy: Dict[str, Optional[float]] = Field(
+    zero_point_energy: Optional[Dict[str, Optional[float]]] = Field(
         None, description="Zero-point energy of the molecule (units: eV)"
     )
 
-    rt: Dict[str, Optional[float]] = Field(
+    rt: Optional[Dict[str, Optional[float]]] = Field(
         None,
         description="R*T, where R is the gas constant and T is temperature, taken "
         "to be 298.15K (units: eV)",
     )
 
-    total_enthalpy: Dict[str, Optional[float]] = Field(
+    total_enthalpy: Optional[Dict[str, Optional[float]]] = Field(
         None, description="Total enthalpy of the molecule at 298.15K (units: eV)"
     )
-    total_entropy: Dict[str, Optional[float]] = Field(
+    total_entropy: Optional[Dict[str, Optional[float]]] = Field(
         None, description="Total entropy of the molecule at 298.15K (units: eV/K)"
     )
 
-    translational_enthalpy: Dict[str, Optional[float]] = Field(
+    translational_enthalpy: Optional[Dict[str, Optional[float]]] = Field(
         None,
         description="Translational enthalpy of the molecule at 298.15K (units: eV)",
     )
-    translational_entropy: Dict[str, Optional[float]] = Field(
+    translational_entropy: Optional[Dict[str, Optional[float]]] = Field(
         None,
         description="Translational entropy of the molecule at 298.15K (units: eV/K)",
     )
-    rotational_enthalpy: Dict[str, Optional[float]] = Field(
+    rotational_enthalpy: Optional[Dict[str, Optional[float]]] = Field(
         None, description="Rotational enthalpy of the molecule at 298.15K (units: eV)"
     )
-    rotational_entropy: Dict[str, Optional[float]] = Field(
+    rotational_entropy: Optional[Dict[str, Optional[float]]] = Field(
         None, description="Rotational entropy of the molecule at 298.15K (units: eV/K)"
     )
-    vibrational_enthalpy: Dict[str, Optional[float]] = Field(
+    vibrational_enthalpy: Optional[Dict[str, Optional[float]]] = Field(
         None, description="Vibrational enthalpy of the molecule at 298.15K (units: eV)"
     )
-    vibrational_entropy: Dict[str, Optional[float]] = Field(
+    vibrational_entropy: Optional[Dict[str, Optional[float]]] = Field(
         None, description="Vibrational entropy of the molecule at 298.15K (units: eV/K)"
     )
 
-    free_energy: Dict[str, Optional[float]] = Field(
+    free_energy: Optional[Dict[str, Optional[float]]] = Field(
         None, description="Gibbs free energy of the molecule at 298.15K (units: eV)"
     )
 
     # vibrational properties
-    vibration_property_ids: Dict[str, str] = Field(
+    vibration_property_ids: Optional[Dict[str, str]] = Field(
         None,
         description="Solvent:property ID map for each VibrationDoc for this molecule.",
     )
 
-    vibration_levels_of_theory: Dict[str, str] = Field(
+    vibration_levels_of_theory: Optional[Dict[str, str]] = Field(
         None,
         description="Solvent:level of theory map for each VibrationDoc for this molecule.",
     )
 
-    frequencies: Dict[str, List[float]] = Field(
+    frequencies: Optional[Dict[str, List[float]]] = Field(
         None, description="List of molecular vibrational frequencies"
     )
 
-    frequency_modes: Dict[str, List[List[List[float]]]] = Field(
+    frequency_modes: Optional[Dict[str, List[List[List[float]]]]] = Field(
         None,
         description="Vibrational frequency modes of the molecule (units: Angstrom)",
     )
 
-    ir_intensities: Dict[str, List[float]] = Field(
+    ir_intensities: Optional[Dict[str, List[float]]] = Field(
         None,
         title="IR intensities",
         description="Intensities for infrared vibrational spectrum peaks",
     )
 
-    ir_activities: Dict[str, List] = Field(
+    ir_activities: Optional[Dict[str, List]] = Field(
         None,
         title="IR activities",
         description="List indicating if frequency-modes are IR-active",
     )
 
     # natural bonding orbitals
-    orbitals_property_ids: Dict[str, str] = Field(
+    orbitals_property_ids: Optional[Dict[str, str]] = Field(
         None,
         description="Solvent:property ID map for each OrbitalDoc for this molecule.",
     )
 
-    orbitals_levels_of_theory: Dict[str, str] = Field(
+    orbitals_levels_of_theory: Optional[Dict[str, str]] = Field(
         None,
         description="Solvent:level of theory map for each OrbitalDoc for this molecule.",
     )
 
-    open_shell: Dict[str, bool] = Field(
+    open_shell: Optional[Dict[str, bool]] = Field(
         None, description="Is this molecule open-shell (spin multiplicity != 1)?"
     )
 
-    nbo_population: Dict[str, Optional[List[NaturalPopulation]]] = Field(
+    nbo_population: Optional[Dict[str, Optional[List[NaturalPopulation]]]] = Field(
         None, description="Natural electron populations of the molecule"
     )
-    nbo_lone_pairs: Dict[str, Optional[List[LonePair]]] = Field(
+    nbo_lone_pairs: Optional[Dict[str, Optional[List[LonePair]]]] = Field(
         None, description="Lone pair orbitals of a closed-shell molecule"
     )
-    nbo_bonds: Dict[str, Optional[List[Bond]]] = Field(
+    nbo_bonds: Optional[Dict[str, Optional[List[Bond]]]] = Field(
         None, description="Bond-like orbitals of a closed-shell molecule"
     )
-    nbo_interactions: Dict[str, Optional[List[Interaction]]] = Field(
+    nbo_interactions: Optional[Dict[str, Optional[List[Interaction]]]] = Field(
         None, description="Orbital-orbital interactions of a closed-shell molecule"
     )
 
-    alpha_population: Dict[str, Optional[List[NaturalPopulation]]] = Field(
+    alpha_population: Optional[Dict[str, Optional[List[NaturalPopulation]]]] = Field(
         None,
         description="Natural electron populations of the alpha electrons of an "
         "open-shell molecule",
     )
-    beta_population: Dict[str, Optional[List[NaturalPopulation]]] = Field(
+    beta_population: Optional[Dict[str, Optional[List[NaturalPopulation]]]] = Field(
         None,
         description="Natural electron populations of the beta electrons of an "
         "open-shell molecule",
     )
-    alpha_lone_pairs: Dict[str, Optional[List[LonePair]]] = Field(
+    alpha_lone_pairs: Optional[Dict[str, Optional[List[LonePair]]]] = Field(
         None, description="Alpha electron lone pair orbitals of an open-shell molecule"
     )
-    beta_lone_pairs: Dict[str, Optional[List[LonePair]]] = Field(
+    beta_lone_pairs: Optional[Dict[str, Optional[List[LonePair]]]] = Field(
         None, description="Beta electron lone pair orbitals of an open-shell molecule"
     )
-    alpha_bonds: Dict[str, Optional[List[Bond]]] = Field(
+    alpha_bonds: Optional[Dict[str, Optional[List[Bond]]]] = Field(
         None, description="Alpha electron bond-like orbitals of an open-shell molecule"
     )
-    beta_bonds: Dict[str, Optional[List[Bond]]] = Field(
+    beta_bonds: Optional[Dict[str, Optional[List[Bond]]]] = Field(
         None, description="Beta electron bond-like orbitals of an open-shell molecule"
     )
-    alpha_interactions: Dict[str, Optional[List[Interaction]]] = Field(
+    alpha_interactions: Optional[Dict[str, Optional[List[Interaction]]]] = Field(
         None,
         description="Alpha electron orbital-orbital interactions of an open-shell molecule",
     )
-    beta_interactions: Dict[str, Optional[List[Interaction]]] = Field(
+    beta_interactions: Optional[Dict[str, Optional[List[Interaction]]]] = Field(
         None,
         description="Beta electron orbital-orbital interactions of an open-shell molecule",
     )
 
     # partial charges
-    partial_charges_property_ids: Dict[str, Dict[str, str]] = Field(
+    partial_charges_property_ids: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="Solvent:method:property ID map for each PartialChargesDoc for this molecule.",
     )
 
-    partial_charges_levels_of_theory: Dict[str, Dict[str, str]] = Field(
+    partial_charges_levels_of_theory: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="Solvent:method:level of theory map for each PartialChargesDoc for this molecule.",
     )
 
-    partial_charges: Dict[str, Dict[str, List[float]]] = Field(
+    partial_charges: Optional[Dict[str, Dict[str, List[float]]]] = Field(
         None,
         description="Atomic partial charges for the molecule using different partitioning schemes "
         "(Mulliken, Restrained Electrostatic Potential, Natural Bonding Orbitals, etc.)",
     )
 
     # partial spins
-    partial_spins_property_ids: Dict[str, Dict[str, str]] = Field(
+    partial_spins_property_ids: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="Solvent:method:property ID map for each PartialSpinsDoc for this molecule.",
     )
 
-    partial_spins_levels_of_theory: Dict[str, Dict[str, str]] = Field(
+    partial_spins_levels_of_theory: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="Solvent:method:level of theory map for each PartialSpinsDoc for this molecule.",
     )
 
-    partial_spins: Dict[str, Dict[str, List[float]]] = Field(
+    partial_spins: Optional[Dict[str, Dict[str, List[float]]]] = Field(
         None,
         description="Atomic partial spins for the molecule using different partitioning schemes "
         "(Mulliken, Natural Bonding Orbitals, etc.)",
     )
 
     # bonding
-    bonding_property_ids: Dict[str, Dict[str, str]] = Field(
+    bonding_property_ids: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="Solvent:method:property ID map for each MoleculeBondingDoc for this molecule.",
     )
 
-    bonding_levels_of_theory: Dict[str, Dict[str, str]] = Field(
+    bonding_levels_of_theory: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="Solvent:method:level of theory map for each MoleculeBondingDoc for this molecule.",
     )
 
-    molecule_graph: Dict[str, Dict[str, MoleculeGraph]] = Field(
+    molecule_graph: Optional[Dict[str, Dict[str, MoleculeGraph]]] = Field(
         None,
         description="Molecular graph representations of the molecule using different "
         "definitions of bonding.",
     )
 
-    bond_types: Dict[str, Dict[str, Dict[str, List[float]]]] = Field(
+    bond_types: Optional[Dict[str, Dict[str, Dict[str, List[float]]]]] = Field(
         None,
         description="Dictionaries of bond types to their length under different "
         "definitions of bonding, e.g. C-O to a list of the lengths of "
         "C-O bonds in Angstrom.",
     )
 
-    bonds: Dict[str, Dict[str, List[Tuple[int, int]]]] = Field(
+    bonds: Optional[Dict[str, Dict[str, List[Tuple[int, int]]]]] = Field(
         None,
         description="List of bonds under different definitions of bonding. Each bond takes "
         "the form (a, b), where a and b are 0-indexed atom indices",
     )
 
-    bonds_nometal: Dict[str, Dict[str, List[Tuple[int, int]]]] = Field(
+    bonds_nometal: Optional[Dict[str, Dict[str, List[Tuple[int, int]]]]] = Field(
         None,
         description="List of bonds under different definitions of bonding with all metal ions "
         "removed. Each bond takes the form in the form (a, b), where a and b are "
@@ -331,125 +331,125 @@ class MoleculeSummaryDoc(PropertyDoc):
     )
 
     # redox properties
-    redox_property_ids: Dict[str, str] = Field(
+    redox_property_ids: Optional[Dict[str, str]] = Field(
         None, description="Solvent:property ID map for each RedoxDoc for this molecule."
     )
 
-    redox_levels_of_theory: Dict[str, str] = Field(
+    redox_levels_of_theory: Optional[Dict[str, str]] = Field(
         None,
         description="Solvent:level of theory map for each RedoxDoc for this molecule.",
     )
 
-    electron_affinity: Dict[str, float] = Field(
+    electron_affinity: Optional[Dict[str, float]] = Field(
         None, description="Vertical electron affinity in eV"
     )
 
-    ea_task_id: Dict[str, MPID] = Field(
+    ea_task_id: Optional[Dict[str, MPID]] = Field(
         None, description="Molecule ID for electron affinity"
     )
 
-    ionization_energy: Dict[str, float] = Field(
+    ionization_energy: Optional[Dict[str, float]] = Field(
         None, description="Vertical ionization energy in eV"
     )
 
-    ie_task_id: Dict[str, MPID] = Field(
+    ie_task_id: Optional[Dict[str, MPID]] = Field(
         None, description="Molecule ID for ionization energy"
     )
 
-    reduction_free_energy: Dict[str, float] = Field(
+    reduction_free_energy: Optional[Dict[str, float]] = Field(
         None, description="Adiabatic free energy of reduction"
     )
 
-    red_molecule_id: Dict[str, MPculeID] = Field(
+    red_molecule_id: Optional[Dict[str, MPculeID]] = Field(
         None, description="Molecule ID for adiabatic reduction"
     )
 
-    oxidation_free_energy: Dict[str, float] = Field(
+    oxidation_free_energy: Optional[Dict[str, float]] = Field(
         None, description="Adiabatic free energy of oxidation"
     )
 
-    ox_molecule_id: Dict[str, MPculeID] = Field(
+    ox_molecule_id: Optional[Dict[str, MPculeID]] = Field(
         None, description="Molecule ID for adiabatic oxidation"
     )
 
-    reduction_potential: Dict[str, float] = Field(
+    reduction_potential: Optional[Dict[str, float]] = Field(
         None,
         description="Reduction potential referenced to the standard hydrogen electrode (SHE) (units: V)",
     )
 
-    oxidation_potential: Dict[str, float] = Field(
+    oxidation_potential: Optional[Dict[str, float]] = Field(
         None,
         description="Oxidation potential referenced to the standard hydrogen electrode (SHE) (units: V)",
     )
 
     # metal binding properties
-    binding_partial_charges_property_id: Dict[str, Dict[str, str]] = Field(
+    binding_partial_charges_property_id: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="ID of PartialChargesDoc used to estimate metal charge",
     )
 
-    binding_partial_spins_property_id: Dict[str, Dict[str, str]] = Field(
+    binding_partial_spins_property_id: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="ID of PartialSpinsDoc used to estimate metal spin",
     )
 
-    binding_partial_charges_lot_solvent: Dict[str, Dict[str, str]] = Field(
+    binding_partial_charges_lot_solvent: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="Combination of level of theory and solvent used to calculate atomic partial charges",
     )
 
-    binding_partial_spins_lot_solvent: Dict[str, Dict[str, str]] = Field(
+    binding_partial_spins_lot_solvent: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="Combination of level of theory and solvent used to calculate atomic partial spins",
     )
 
-    binding_charge_spin_method: Dict[str, Dict[str, str]] = Field(
+    binding_charge_spin_method: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="The method used for partial charges and spins (must be the same).",
     )
 
-    binding_bonding_property_id: Dict[str, Dict[str, str]] = Field(
+    binding_bonding_property_id: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="ID of MoleculeBondingDoc used to detect bonding in this molecule",
     )
 
-    binding_bonding_lot_solvent: Dict[str, Dict[str, str]] = Field(
+    binding_bonding_lot_solvent: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="Combination of level of theory and solvent used to determine the coordination environment "
         "of the metal atom or ion",
     )
 
-    binding_bonding_method: Dict[str, Dict[str, str]] = Field(
+    binding_bonding_method: Optional[Dict[str, Dict[str, str]]] = Field(
         None, description="The method used for to define bonding."
     )
 
-    binding_thermo_property_id: Dict[str, Dict[str, str]] = Field(
+    binding_thermo_property_id: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="ID of MoleculeThermoDoc used to obtain this molecule's thermochemistry",
     )
 
-    binding_thermo_lot_solvent: Dict[str, Dict[str, str]] = Field(
+    binding_thermo_lot_solvent: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="Combination of level of theory and solvent used for uncorrected thermochemistry",
     )
 
-    binding_thermo_correction_lot_solvent: Dict[str, Dict[str, str]] = Field(
+    binding_thermo_correction_lot_solvent: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
         description="Combination of level of theory and solvent used to correct the electronic energy",
     )
 
-    binding_thermo_combined_lot_solvent: Dict[str, Dict[str, str]] = Field(
+    binding_thermo_combined_lot_solvent: Optional[Dict[str, Dict[str, str]]] = Field(
         None,
-        descrption="Combination of level of theory and solvent used for molecular thermochemistry, combining "
+        description="Combination of level of theory and solvent used for molecular thermochemistry, combining "
         "both the frequency calculation and (potentially) the single-point energy correction.",
     )
 
-    binding_data: Dict[str, Dict[str, List[MetalBindingData]]] = Field(
+    binding_data: Optional[Dict[str, Dict[str, List[MetalBindingData]]]] = Field(
         None, description="Binding data for each metal atom or ion in the molecule"
     )
 
     # has props
-    has_props: List[HasProps] = Field(
+    has_props: Optional[List[HasProps]] = Field(
         None, description="List of properties that are available for a given material."
     )
 
