@@ -34,7 +34,7 @@ def get_free_energy(energy, enthalpy, entropy, temperature=298.15, convert_energ
 
 
 class MoleculeThermoDoc(PropertyDoc):
-    property_name = "thermo"
+    property_name: str = "thermo"
 
     electronic_energy: float = Field(
         ..., description="Electronic energy of the molecule (units: eV)"
@@ -46,39 +46,39 @@ class MoleculeThermoDoc(PropertyDoc):
         "theory used to correct the electronic energy?",
     )
 
-    base_level_of_theory: LevelOfTheory = Field(
+    base_level_of_theory: Optional[LevelOfTheory] = Field(
         None, description="Level of theory used for uncorrected thermochemistry."
     )
 
-    base_solvent: str = Field(
+    base_solvent: Optional[str] = Field(
         None,
         description="String representation of the solvent "
         "environment used for uncorrected thermochemistry.",
     )
 
-    base_lot_solvent: str = Field(
+    base_lot_solvent: Optional[str] = Field(
         None,
         description="String representation of the level of theory and solvent "
         "environment used for uncorrected thermochemistry.",
     )
 
-    correction_level_of_theory: LevelOfTheory = Field(
+    correction_level_of_theory: Optional[LevelOfTheory] = Field(
         None, description="Level of theory used to correct the electronic energy."
     )
 
-    correction_solvent: str = Field(
+    correction_solvent: Optional[str] = Field(
         None,
         description="String representation of the solvent "
         "environment used to correct the electronic energy.",
     )
 
-    correction_lot_solvent: str = Field(
+    correction_lot_solvent: Optional[str] = Field(
         None,
         description="String representation of the level of theory and solvent "
         "environment used to correct the electronic energy.",
     )
 
-    combined_lot_solvent: str = Field(
+    combined_lot_solvent: Optional[str] = Field(
         None,
         description="String representation of the level of theory and solvent "
         "environment used to generate this ThermoDoc, combining "
@@ -86,45 +86,45 @@ class MoleculeThermoDoc(PropertyDoc):
         "single-point energy correction.",
     )
 
-    zero_point_energy: float = Field(
+    zero_point_energy: Optional[float] = Field(
         None, description="Zero-point energy of the molecule (units: eV)"
     )
 
-    rt: float = Field(
+    rt: Optional[float] = Field(
         None,
         description="R*T, where R is the gas constant and T is temperature, taken "
         "to be 298.15K (units: eV)",
     )
 
-    total_enthalpy: float = Field(
+    total_enthalpy: Optional[float] = Field(
         None, description="Total enthalpy of the molecule at 298.15K (units: eV)"
     )
-    total_entropy: float = Field(
+    total_entropy: Optional[float] = Field(
         None, description="Total entropy of the molecule at 298.15K (units: eV/K)"
     )
 
-    translational_enthalpy: float = Field(
+    translational_enthalpy: Optional[float] = Field(
         None,
         description="Translational enthalpy of the molecule at 298.15K (units: eV)",
     )
-    translational_entropy: float = Field(
+    translational_entropy: Optional[float] = Field(
         None,
         description="Translational entropy of the molecule at 298.15K (units: eV/K)",
     )
-    rotational_enthalpy: float = Field(
+    rotational_enthalpy: Optional[float] = Field(
         None, description="Rotational enthalpy of the molecule at 298.15K (units: eV)"
     )
-    rotational_entropy: float = Field(
+    rotational_entropy: Optional[float] = Field(
         None, description="Rotational entropy of the molecule at 298.15K (units: eV/K)"
     )
-    vibrational_enthalpy: float = Field(
+    vibrational_enthalpy: Optional[float] = Field(
         None, description="Vibrational enthalpy of the molecule at 298.15K (units: eV)"
     )
-    vibrational_entropy: float = Field(
+    vibrational_entropy: Optional[float] = Field(
         None, description="Vibrational entropy of the molecule at 298.15K (units: eV/K)"
     )
 
-    free_energy: float = Field(
+    free_energy: Optional[float] = Field(
         None, description="Gibbs free energy of the molecule at 298.15K (units: eV)"
     )
 
