@@ -1,9 +1,4 @@
-from pathlib import Path
-
-try:
-    import emmet.core.qchem.calc_types.enums
-except ImportError:
-    import emmet.core.qchem.calc_types.generate
+"""Module defining Q-Chem calculation types."""
 
 from emmet.core.qchem.calc_types.enums import CalcType, LevelOfTheory, TaskType
 from emmet.core.qchem.calc_types.utils import (
