@@ -68,6 +68,13 @@ class StoreTrajectoryOption(ValueEnum):
     NO = "no"
 
 
+class CalculationBaseModel(BaseModel):
+    """Wrapper around pydantic BaseModel with extra functionality."""
+
+    def get(self, key: Any, default_value: Optional[Any] = None) -> Any:
+        return getattr(self, key, default_value)
+
+
 class PotcarSpec(BaseModel):
     """Document defining a VASP POTCAR specification."""
 
@@ -116,7 +123,7 @@ class PotcarSpec(BaseModel):
         return [cls.from_potcar_single(p) for p in potcar]
 
 
-class CalculationInput(BaseModel):
+class CalculationInput(CalculationBaseModel):
     """Document defining VASP calculation inputs."""
 
     incar: Optional[Dict[str, Any]] = Field(
@@ -168,15 +175,22 @@ class CalculationInput(BaseModel):
             for k, w in zip(vasprun.actual_kpoints, vasprun.actual_kpoints_weights)
         ]
 
+        parameters = dict(vasprun.parameters).copy()
+        incar = dict(vasprun.incar)
+        if metagga := incar.get("METAGGA"):
+            # Per issue #960, the METAGGA tag is populated in the
+            # INCAR field of vasprun.xml, and not parameters
+            parameters.update({"METAGGA": metagga})
+
         return cls(
             structure=vasprun.initial_structure,
-            incar=dict(vasprun.incar),
+            incar=incar,
             kpoints=kpoints_dict,
             nkpoints=len(kpoints_dict["actual_kpoints"]),
             potcar=[s.split()[0] for s in vasprun.potcar_symbols],
             potcar_spec=vasprun.potcar_spec,
             potcar_type=[s.split()[0] for s in vasprun.potcar_symbols],
-            parameters=dict(vasprun.parameters),
+            parameters=parameters,
             lattice_rec=vasprun.initial_structure.lattice.reciprocal_lattice,
             is_hubbard=vasprun.is_hubbard,
             hubbards=vasprun.hubbards,
@@ -369,6 +383,13 @@ class CalculationOutput(BaseModel):
         description="The magnetization density, defined as total_mag/volume "
         "(units of A^-3)",
     )
+    dielectric: Optional[dict[str, list]] = Field(
+        None,
+        description="Energy of incident photons in ev and real and imaginary parts of the dielectric tensor",
+    )
+    optical_absorption_coeff: Optional[list] = Field(
+        None, description="Optical absorption coefficient in cm^-1"
+    )
     epsilon_static: Optional[ListMatrix3D] = Field(
         None, description="The high-frequency dielectric constant"
     )
@@ -430,6 +451,7 @@ class CalculationOutput(BaseModel):
         locpot: Optional[Locpot] = None,
         elph_poscars: Optional[List[Path]] = None,
         store_trajectory: StoreTrajectoryOption = StoreTrajectoryOption.NO,
+        store_onsite_density_matrices: bool = False,
     ) -> "CalculationOutput":
         """
         Create a VASP output document from VASP outputs.
@@ -452,7 +474,8 @@ class CalculationOutput(BaseModel):
             Different value tune the amount of data from the ionic_steps
             stored in the Trajectory.
             If not NO, the `ionic_steps` field is left as None.
-
+        store_onsite_density_matrices
+            Whether to store the onsite density matrices from the OUTCAR.
         Returns
         -------
             The VASP calculation output document.
@@ -510,7 +533,8 @@ class CalculationOutput(BaseModel):
         if outcar and contcar:
             outcar_dict = outcar.as_dict()
             outcar_dict.pop("run_stats")
-
+            if not store_onsite_density_matrices and outcar.has_onsite_density_matrices:
+                outcar_dict.pop("onsite_density_matrices")
             # use structure from CONTCAR as it is written to
             # greater precision than in the vasprun
             # but still need to copy the charge over
@@ -547,7 +571,6 @@ class CalculationOutput(BaseModel):
                 temp = str(elph_poscar.name).replace("POSCAR.T=", "").replace(".gz", "")
                 elph_structures["temperatures"].append(temp)
                 elph_structures["structures"].append(Structure.from_file(elph_poscar))
-
         return cls(
             structure=structure,
             energy=vasprun.final_energy,
@@ -570,7 +593,7 @@ class CalculationOutput(BaseModel):
         )
 
 
-class Calculation(BaseModel):
+class Calculation(CalculationBaseModel):
     """Full VASP calculation inputs and outputs."""
 
     dir_name: Optional[str] = Field(
@@ -631,6 +654,7 @@ class Calculation(BaseModel):
         strip_dos_projections: bool = False,
         store_volumetric_data: Optional[Tuple[str]] = None,
         store_trajectory: StoreTrajectoryOption = StoreTrajectoryOption.NO,
+        store_onsite_density_matrices: bool = False,
         vasprun_kwargs: Optional[Dict] = None,
     ) -> Tuple["Calculation", Dict[VaspObject, Dict]]:
         """
@@ -705,6 +729,8 @@ class Calculation(BaseModel):
             - NO: Trajectory is not Stored.
             If not NO, :obj:'.CalculationOutput.ionic_steps' is set to None
             to reduce duplicating information.
+        store_onsite_density_matrices
+            Whether to store the onsite density matrices from the OUTCAR.
         vasprun_kwargs
             Additional keyword arguments that will be passed to the Vasprun init.
 
@@ -771,6 +797,7 @@ class Calculation(BaseModel):
             locpot=locpot,
             elph_poscars=elph_poscars,
             store_trajectory=store_trajectory,
+            store_onsite_density_matrices=store_onsite_density_matrices,
         )
         if store_trajectory != StoreTrajectoryOption.NO:
             exclude_from_trajectory = ["structure"]
@@ -801,7 +828,7 @@ class Calculation(BaseModel):
 
         # MD run
         if vasprun.parameters.get("IBRION", -1) == 0:
-            if vasprun.parameters.get("NSW", 0) == vasprun.nionic_steps:
+            if vasprun.parameters.get("NSW", 0) == vasprun.md_n_steps:
                 has_vasp_completed = TaskState.SUCCESS
             else:
                 has_vasp_completed = TaskState.FAILED
